aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/lib
diff options
context:
space:
mode:
authorGravatar ncteisen <ncteisen@gmail.com>2017-11-21 13:55:52 -0500
committerGravatar ncteisen <ncteisen@gmail.com>2017-11-21 13:55:52 -0500
commit264560ff4a497de14e070de0323dd5eb48d96b6f (patch)
tree3e47eedf4cb6ceaf1478ae2e221b59b8deace305 /src/core/lib
parentb8ec2382115bb81007515986f5dacfa2d56b6b8f (diff)
Reviewer feedback
Diffstat (limited to 'src/core/lib')
-rw-r--r--src/core/lib/support/abstract.h2
-rw-r--r--src/core/lib/support/manual_constructor.h20
2 files changed, 11 insertions, 11 deletions
diff --git a/src/core/lib/support/abstract.h b/src/core/lib/support/abstract.h
index ddf472bc37..5498769a7d 100644
--- a/src/core/lib/support/abstract.h
+++ b/src/core/lib/support/abstract.h
@@ -21,7 +21,7 @@
// This is needed to support abstract base classes in the c core. Since gRPC
// doesn't have a c++ runtime, it will hit a linker error on delete unless
-// a we define a virtual operator delete. See this blog for more info:
+// we define a virtual operator delete. See this blog for more info:
// https://eli.thegreenplace.net/2015/c-deleting-destructors-and-virtual-operator-delete/
#define GRPC_ABSTRACT_BASE_CLASS \
static void operator delete(void* p) { abort(); }
diff --git a/src/core/lib/support/manual_constructor.h b/src/core/lib/support/manual_constructor.h
index 25731936b1..fda7653dbc 100644
--- a/src/core/lib/support/manual_constructor.h
+++ b/src/core/lib/support/manual_constructor.h
@@ -35,25 +35,25 @@ namespace grpc_core {
// in this file.
namespace manual_ctor_impl {
-// is_one_of returns true it a class, Needle, is present in a variadic list of
-// classes, Haystack.
-template <class Needle, class... Haystack>
+// is_one_of returns true it a class, Member, is present in a variadic list of
+// classes, List.
+template <class Member, class... List>
class is_one_of;
-template <class Needle, class... Haystack>
-class is_one_of<Needle, Needle, Haystack...> {
+template <class Member, class... List>
+class is_one_of<Member, Member, List...> {
public:
static constexpr const bool value = true;
};
-template <class Needle, class A, class... Haystack>
-class is_one_of<Needle, A, Haystack...> {
+template <class Member, class A, class... List>
+class is_one_of<Member, A, List...> {
public:
- static constexpr const bool value = is_one_of<Needle, Haystack...>::value;
+ static constexpr const bool value = is_one_of<Member, List...>::value;
};
-template <class Needle>
-class is_one_of<Needle> {
+template <class Member>
+class is_one_of<Member> {
public:
static constexpr const bool value = false;
};